==> eiffelstudio-18.07.10.1981.tar: F_code/C12/uc566.c <==
/*
 * Code for class UC_V510_CTYPE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "uc566.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {UC_V510_CTYPE}.lower_code */
EIF_INTEGER_32 F1255_11785 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLIU(5);
	
	RTEAA("lower_code", 1254, Current, 4, 1, 18574);
	RTGC;
	RTHOOK(1);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	RTHOOK(2);
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	RTHOOK(3);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	RTHOOK(4);
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	RTHOOK(5);
	tr1 = RTOSCF(11783,F1254_11783,(Current));
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc1));
	/* END INLINED CODE */
	tr1 = tr3;
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc2));
	/* END INLINED CODE */
	tr1 = tr3;
	Result = F851_7692(RTCW(tr1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
	RTHOOK(6);
	if ((EIF_BOOLEAN)(Result == ((EIF_INTEGER_32) -1L))) {
		RTHOOK(7);
		RTHOOK(8);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) arg1;
	}
	RTHOOK(9);
	RTLE;
	RTEE;
	return Result;
}

/* {UC_V510_CTYPE}.upper_code */
EIF_INTEGER_32 F1255_11786 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLIU(5);
	
	RTEAA("upper_code", 1254, Current, 4, 1, 18575);
	RTGC;
	RTHOOK(1);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	RTHOOK(2);
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	RTHOOK(3);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	RTHOOK(4);
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	RTHOOK(5);
	tr1 = RTOSCF(11759,F1253_11759,(Current));
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc1));
	/* END INLINED CODE */
	tr1 = tr3;
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc2));
	/* END INLINED CODE */
	tr1 = tr3;
	Result = F851_7692(RTCW(tr1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
	RTHOOK(6);
	if ((EIF_BOOLEAN)(Result == ((EIF_INTEGER_32) -1L))) {
		RTHOOK(7);
		RTHOOK(8);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) arg1;
	}
	RTHOOK(9);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit566 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C12/uc566.c <==
/*
 * Code for class UC_V510_CTYPE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "uc566.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {UC_V510_CTYPE}.valid_code */
EIF_BOOLEAN F1277_10973 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (arg1 >= ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN) (arg1 <= ((EIF_INTEGER_32) 1114111L)));
}

/* {UC_V510_CTYPE}.lower_code */
EIF_INTEGER_32 F1277_10975 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLIU(4);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	tr1 = RTOSCF(10972,F1276_10972, (Current));
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc1));
	/* END INLINED CODE */
	tr1 = tr3;
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc2));
	/* END INLINED CODE */
	tr1 = tr3;
	Result = F883_4372(RTCW(tr1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
	if ((EIF_BOOLEAN)(Result == ((EIF_INTEGER_32) -1L))) {
		RTLE;
		return (EIF_INTEGER_32) arg1;
	}
	RTLE;
	return Result;
}

/* {UC_V510_CTYPE}.upper_code */
EIF_INTEGER_32 F1277_10976 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLIU(4);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	tr1 = RTOSCF(10948,F1275_10948, (Current));
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc1));
	/* END INLINED CODE */
	tr1 = tr3;
	/* INLINED CODE (SPECIAL.item) */
	tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc2));
	/* END INLINED CODE */
	tr1 = tr3;
	Result = F883_4372(RTCW(tr1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
	if ((EIF_BOOLEAN)(Result == ((EIF_INTEGER_32) -1L))) {
		RTLE;
		return (EIF_INTEGER_32) arg1;
	}
	RTLE;
	return Result;
}

void EIF_Minit566 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
